ifgen.config package — docs

Skip to main content
`Ctrl`+`K`

# ifgen.config package

## Submodules

## ifgen.config.svd module

A module implementing an SVD-command configuration interface for the package.

class ifgen.config.svd.SvdConfig(data: dict[str, str | int | float | bool | None | dict[str, str | int | float | bool | None] | list[str | int | float | bool | None]] = None, schemas: SchemaMap = None, dest_attr: str = 'data', verify: bool = True)

  Bases: `IfgenDictCodec`, `BasicDictCodec`

  The top-level configuration object for the package.

## Module contents

A module implementing a configuration interface for the package.

class ifgen.config.Config(data: dict[str, str | int | float | bool | None | dict[str, str | int | float | bool | None] | list[str | int | float | bool | None]] = None, schemas: SchemaMap = None, dest_attr: str = 'data', verify: bool = True)

  Bases: `IfgenDictCodec`, `BasicDictCodec`

  The top-level configuration object for the package.

  init(data: dict[str, str | int | float | bool | None | dict[str, str | int | float | bool | None] | list[str | int | float | bool | None]]) → None

    Initialize this instance.

ifgen.config.load(path: Path | str | None) → Config

  Load a configuration object.